%define rpmrelease %{nil}
%define debug_package %{nil}

Name:		rear
Version:	2.6
%define subrel 1
Release:	%mkrel 2
Summary:	Relax and Recover (ReaR) is a Linux Disaster Recovery framework
Group:		Archiving/Backup
License:	GPLv3
URL:		http://relax-and-recover.org/
Source0:	https://github.com/rear/rear/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:		89b61793d80bc2cb2abe47a7d0549466fb087d16.patch
# rear contains only bash scripts plus documentation so that on first glance it could be "BuildArch: noarch"
# but actually it is not "noarch" because it only works on those architectures that are explicitly supported.
# Of course the rear bash scripts can be installed on any architecture just as any binaries can be installed on any architecture.
# But the meaning of architecture dependent packages should be on what architectures they will work.
# Therefore only those architectures that are actually supported are explicitly listed.
# This avoids that rear can be "just installed" on architectures that are actually not supported (e.g. ARM or IBM z Systems):
ExclusiveArch:	%ix86 x86_64 ppc ppc64 ppc64le ia64
# Furthermore for some architectures it requires architecture dependent packages (like syslinux for x86 and x86_64)
# so that rear must be architecture dependent because ifarch conditions never match in case of "BuildArch: noarch"
# see the GitHub issue https://github.com/rear/rear/issues/629
%ifarch %ix86 x86_64
Requires:	syslinux
%endif
# In the end this should tell the user that rear is known to work only on ix86 x86_64 ppc ppc64 ppc64le ia64
# and on ix86 x86_64 syslinux is explicitly required to make the bootable ISO image
# (in addition to the default installed bootloader grub2) while on ppc ppc64 the
# default installed bootloader yaboot is also useed to make the bootable ISO image.

### Dependencies on all distributions
Requires:	binutils
Requires:	ethtool
Requires:	cdrkit-genisoimage
Requires:	gawk
Requires:	gzip
Requires:	iproute2
Requires:	iputils
Requires:	openssl
Requires:	parted
Requires:	rpcbind
Requires:	tar
Requires:	attr
Requires:	bc

### We drop LSB requirements because it pulls in too many dependencies
### The OS is hardcoded in /etc/rear/os.conf instead
#Requires:	lsb

%description
Relax and Recover (abbreviated rear) is a highly modular disaster recovery
framework for GNU/Linux based systems, but can be easily extended to other
UNIX alike systems. The disaster recovery information (and maybe the backups)
can be stored via the network, local on hard disks or USB devices, DVD/CD-R,
tape, etc. The result is also a boot-able image that is capable of booting via
PXE, DVD/CD and USB media.

Relax and Recover integrates with other backup software and provides integrated
bare metal disaster recovery abilities to the compatible backup software.


%prep
%setup -q
%autopatch -p1

%build
# no code to compile - all bash scripts

%install
# create directories
mkdir -vp \
	%{buildroot}%{_mandir}/man8 \
	%{buildroot}%{_datadir} \
	%{buildroot}%{_sysconfdir} \
	%{buildroot}%{_sbindir} \
	%{buildroot}%{_localstatedir}/lib/rear

# copy rear components into directories
cp -av usr/share/rear %{buildroot}%{_datadir}/
cp -av usr/sbin/rear %{buildroot}%{_sbindir}/
cp -av etc/rear %{buildroot}%{_sysconfdir}/

# patch rear main script with correct locations for rear components
sed -i	-e 's#^CONFIG_DIR=.*#CONFIG_DIR="%{_sysconfdir}/rear"#' \
	-e 's#^SHARE_DIR=.*#SHARE_DIR="%{_datadir}/rear"#' \
	-e 's#^VAR_DIR=.*#VAR_DIR="%{_localstatedir}/lib/rear"#' \
	%{buildroot}%{_sbindir}/rear

# update man page with correct locations
sed	-e 's#/etc#%{_sysconfdir}#' \
	-e 's#/usr/sbin#%{_sbindir}#' \
	-e 's#/usr/share#%{_datadir}#' \
	-e 's#/usr/share/doc/packages#%{_docdir}#' \
	doc/%{name}.8 >%{buildroot}%{_mandir}/man8/%{name}.8

# remove doc files under  %%{buildroot}/usr/share/rear
rm -f %{buildroot}%{_datadir}/rear/README
rm -f %{buildroot}%{_datadir}/rear/COPYING
rm -f %{buildroot}%{_datadir}/rear/AUTHORS
rm -f %{buildroot}%{_datadir}/rear/TODO
rm -rf %{buildroot}%{_datadir}/rear/doc/*

%files
%doc README* MAINTAINERS
%{_sbindir}/rear
%{_datadir}/rear
%{_localstatedir}/lib/rear
%{_mandir}/man8/*
%config(noreplace) %{_sysconfdir}/rear


%changelog
* Thu Apr 11 2024 ns80 <ns80> 2.6-2.1.mga9
+ Revision: 2056547
- add an upstream patch for CVE-2024-23301 (mga#33085)

* Tue Mar 15 2022 umeabot <umeabot> 2.6-2.mga9
+ Revision: 1793425
- Mageia 9 Mass Rebuild

* Wed Mar 03 2021 daviddavid <daviddavid> 2.6-1.mga9
+ Revision: 1696933
- new version: 2.6
+ tv <tv>
- fix license

* Fri Feb 14 2020 umeabot <umeabot> 2.4-4.mga8
+ Revision: 1522780
- Mageia 8 Mass Rebuild

* Thu Feb 07 2019 daviddavid <daviddavid> 2.4-3.mga7
+ Revision: 1363925
- finally can't be a noarch pkg see the GitHub
  issue https://github.com/rear/rear/issues/629

* Wed Feb 06 2019 daviddavid <daviddavid> 2.4-2.mga7
+ Revision: 1363579
- fix deps: we don't have lsb on aarch64

* Wed Jan 02 2019 daviddavid <daviddavid> 2.4-1.mga7
+ Revision: 1348578
- new version: 2.4

* Fri Sep 21 2018 umeabot <umeabot> 2.3-2.mga7
+ Revision: 1290760
- Mageia 7 Mass Rebuild

* Thu Apr 19 2018 kekepower <kekepower> 2.3-1.mga7
+ Revision: 1220166
- Update to version 2.3

* Thu Feb 04 2016 umeabot <umeabot> 1.14-8.mga6
+ Revision: 934424
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.14-7.mga5
+ Revision: 747718
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.14-6.mga5
+ Revision: 688630
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.14-5.mga4
+ Revision: 517996
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.14-4.mga3
+ Revision: 380263
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 13 2012 shlomif <shlomif> 1.14-3.mga3
+ Revision: 330396
- New version 1.14 - moved to GitHub/etc.

* Thu Apr 05 2012 dams <dams> 1.11.0-3.mga2
+ Revision: 228653
+ rebuild (emptylog)

* Sat Feb 18 2012 misc <misc> 1.11.0-2.mga2
+ Revision: 210468
- fix deps

* Tue Feb 07 2012 shlomif <shlomif> 1.11.0-1.mga2
+ Revision: 206105
- imported package rear


* Tue Feb 07 2012 Johnny A. Solbu <solbu@mandriva.org> 1.11.0-1
- Import Fedora package
- spec cleanup
- Don't ship COPYING as the license doesn't require it

* Mon May 23 2011 Gratien D'haese <gdha at sourceforge.net> - 1.11.0-1
- placeholder for release

* Mon Jan 24 2011 Gratien D'haese <gdha at sourceforge.net> - 1.9-1
- New development release with P2V, V2V functionality, and more
- added AUTHORS, TODO to %%doc and rm from datadir

* Fri Jun 04 2010 Gratien D'haese <gdha at sourceforge.net> - 1.7.25-1
- added the %%ifarch part for syslinux to avoid warning on ppc/ppc64

* Thu Apr 02 2009 Gratien D'haese <gdha at sourceforge.net> - 1.7.20-1
- update %%_localstatedir/rear to %%_localstatedir/lib/rear

* Mon Mar 16 2009 Gratien D'haese <gdha at sourceforge.net> - 1.7.19-1
- updated description, made the spec file a bit more readable
- changed BuildArchives in BuildArch

* Fri Mar 13 2009 Gratien D'haese <gdha at sourceforge.net> - 1.7.17-1
- do not gzip man page in spec file - rpmbuild will do this for us
- added extra %%doc line for excluding man page from doc itself

* Tue Feb 04 2009 Gratien D'haese <gdha at sourceforge.net> - 1.7.15-1
- update the Fedora spec file with the 1.7.14 items
- added VAR_DIR (%%{_localstatedir}) variable to rear for /var/rear/recovery system data

* Thu Jan 29 2009 Schlomo Schapiro <rear at schlomo.schapiro.org> - 1.7.14-1
- added man page

* Wed Dec 17 2008 Gratien D'haese <gdha at sourceforge.net> - 1.7.10-1
- remove contrib entry from %%doc line in spec file

* Mon Dec 01 2008 Gratien D'haese <gdha at sourceforge.net> - 1.7.9-1
- copy rear.sourcespec according OS_VENDOR
- correct rear.spec file according comment 11 of bugzilla #468189

* Mon Oct 27 2008 Gratien D'haese <gdha at sourceforge.net> - 1.7.8-1
- Fix rpmlint error/warnings for Fedora packaging
- updated the Summary line and %%install section

* Thu Oct 24 2008 Gratien D'haese <gdha at sourceforge.net> - 1.7.7-1
- rewrote rear.spec for Fedora Packaging request

* Tue Aug 28 2006 Schlomo Schapiro <rear at schlomo.schapiro.org> - 1.0-1
- Initial RPM Release
